==> firefox-3.5.10.source.tar.bz2: mozilla-1.9.1/browser/base/content/test/browser_bug477014.js <==
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is bug 477014 test.
 *
 * The Initial Developer of the Original Code is
 * Mozilla Corporation
 * Portions created by the Initial Developer are Copyright (C) 2009
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Asaf Romano <mano@mozilla.com> (Original Author)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

// That's a gecko!
const iconURLSpec = "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABGdBTUEAAK/INwWK6QAAABl0RVh0U29mdHdhcmUAQWRvYmUgSW1hZ2VSZWFkeXHJZTwAAAHWSURBVHjaYvz//z8DJQAggJiQOe/fv2fv7Oz8rays/N+VkfG/iYnJfyD/1+rVq7ffu3dPFpsBAAHEAHIBCJ85c8bN2Nj4vwsDw/8zQLwKiO8CcRoQu0DxqlWrdsHUwzBAAIGJmTNnPgYa9j8UqhFElwPxf2MIDeIrKSn9FwSJoRkAEEAM0DD4DzMAyPi/G+QKY4hh5WAXGf8PDQ0FGwJ22d27CjADAAIIrLmjo+MXA9R2kAHvGBA2wwx6B8W7od6CeQcggKCmCEL8bgwxYCbUIGTDVkHDBia+CuotgACCueD3TDQN75D4xmAvCoK9ARMHBzAw0AECiBHkAlC0Mdy7x9ABNA3obAZXIAa6iKEcGlMVQHwWyjYuL2d4v2cPg8vZswx7gHyAAAK7AOif7SAbOqCmn4Ha3AHFsIDtgPq/vLz8P4MSkJ2W9h8ggBjevXvHDo4FQUQg/kdypqCg4H8lUIACnQ/SOBMYI8bAsAJFPcj1AAEEjwVQqLpAbXmH5BJjqI0gi9DTAAgDBBCcAVLkgmQ7yKCZxpCQxqUZhAECCJ4XgMl493ug21ZD+aDAXH0WLM4A9MZPXJkJIIAwTAR5pQMalaCABQUULttBGCCAGCnNzgABBgAMJ5THwGvJLAAAAABJRU5ErkJggg==";
var testPage="data:text/plain,test bug 477014";

function test() {
  waitForExplicitFinish();

  var newWindow;
  var tabToDetach;

  function onPageShow(event) {
    // we get here if the test is executed before the pageshow
    // event for the window's first tab
    if (!tabToDetach ||
         tabToDetach.linkedBrowser.contentDocument != event.target) {
        return;
    }

    if (!newWindow) {
      var pageShowFunc = arguments.callee;
      gBrowser.removeEventListener("pageshow", pageShowFunc, false);

      // prepare the tab (set icon and busy state)
      // we have to set these only after onState* notification, otherwise
      // they're overriden
      setTimeout(function() {
        gBrowser.setIcon(tabToDetach, iconURLSpec);
        tabToDetach.setAttribute("busy", "true");

        // detach and set the listener on the new window
        newWindow = gBrowser.replaceTabWithWindow(tabToDetach);
        // wait for gBrowser to come along
        function onLoad(event) {
          newWindow.gBrowser
                   .addEventListener("pageshow", pageShowFunc, false);
          newWindow.removeEventListener("load", arguments.callee, false);
        }
        newWindow.addEventListener("load", onLoad, false);
      }, 0);
      return;
    }

    is(newWindow.gBrowser.selectedTab.hasAttribute("busy"), true);
    is(newWindow.gBrowser.selectedTab.linkedBrowser.mIconURL,iconURLSpec);
    newWindow.close();
    finish();
  }

  gBrowser.addEventListener("pageshow", onPageShow, false);
  tabToDetach = gBrowser.addTab(testPage);
}

==> firefox-4.0.source.tar.bz2: mozilla-2.0/browser/base/content/test/browser_bug477014.js <==
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is bug 477014 test.
 *
 * The Initial Developer of the Original Code is
 * Mozilla Corporation
 * Portions created by the Initial Developer are Copyright (C) 2009
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Asaf Romano <mano@mozilla.com> (Original Author)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

// That's a gecko!
const iconURLSpec = "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABGdBTUEAAK/INwWK6QAAABl0RVh0U29mdHdhcmUAQWRvYmUgSW1hZ2VSZWFkeXHJZTwAAAHWSURBVHjaYvz//z8DJQAggJiQOe/fv2fv7Oz8rays/N+VkfG/iYnJfyD/1+rVq7ffu3dPFpsBAAHEAHIBCJ85c8bN2Nj4vwsDw/8zQLwKiO8CcRoQu0DxqlWrdsHUwzBAAIGJmTNnPgYa9j8UqhFElwPxf2MIDeIrKSn9FwSJoRkAEEAM0DD4DzMAyPi/G+QKY4hh5WAXGf8PDQ0FGwJ22d27CjADAAIIrLmjo+MXA9R2kAHvGBA2wwx6B8W7od6CeQcggKCmCEL8bgwxYCbUIGTDVkHDBia+CuotgACCueD3TDQN75D4xmAvCoK9ARMHBzAw0AECiBHkAlC0Mdy7x9ABNA3obAZXIAa6iKEcGlMVQHwWyjYuL2d4v2cPg8vZswx7gHyAAAK7AOif7SAbOqCmn4Ha3AHFsIDtgPq/vLz8P4MSkJ2W9h8ggBjevXvHDo4FQUQg/kdypqCg4H8lUIACnQ/SOBMYI8bAsAJFPcj1AAEEjwVQqLpAbXmH5BJjqI0gi9DTAAgDBBCcAVLkgmQ7yKCZxpCQxqUZhAECCJ4XgMl493ug21ZD+aDAXH0WLM4A9MZPXJkJIIAwTAR5pQMalaCABQUULttBGCCAGCnNzgABBgAMJ5THwGvJLAAAAABJRU5ErkJggg==";
var testPage="data:text/plain,test bug 477014";

function test() {
  waitForExplicitFinish();

  var newWindow;
  var tabToDetach;

  function onPageShow(event) {
    // we get here if the test is executed before the pageshow
    // event for the window's first tab
    if (!tabToDetach ||
        tabToDetach.linkedBrowser.contentDocument != event.target)
      return;

    if (!newWindow) {
      gBrowser.removeEventListener("pageshow", onPageShow, false);

      // prepare the tab (set icon and busy state)
      // we have to set these only after onState* notification, otherwise
      // they're overriden
      setTimeout(function() {
        gBrowser.setIcon(tabToDetach, iconURLSpec);
        tabToDetach.setAttribute("busy", "true");

        // detach and set the listener on the new window
        newWindow = gBrowser.replaceTabWithWindow(tabToDetach);
        // wait for gBrowser to come along
        function onLoad(event) {
          newWindow.gBrowser
                   .addEventListener("pageshow", onPageShow, false);
          newWindow.removeEventListener("load", arguments.callee, false);
        }
        newWindow.addEventListener("load", onLoad, false);
      }, 0);
      return;
    }

    is(newWindow.gBrowser.selectedTab.hasAttribute("busy"), true);
    is(newWindow.gBrowser.getIcon(), iconURLSpec);
    newWindow.close();
    finish();
  }

  gBrowser.addEventListener("pageshow", onPageShow, false);
  tabToDetach = gBrowser.addTab(testPage);
}
